package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,``@$!````T!X```````!``````````%@!`0``
M````0P```$``.``*`$``&0`8``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```"4`@``````
M`)0"````````E`(````````E`````````"4``````````0`````````!````
M!0```````````````````````````````````-BC````````V*,`````````
M``$```````$````&````T/L```````#0^P$``````-#[`0``````@`0`````
M``"H!````````````0```````@````8```#@^P```````.#[`0``````X/L!
M``````#P`0```````/`!````````"``````````$````!````'`"````````
M<`(```````!P`@```````"0`````````)``````````$``````````0````$
M````N*,```````"XHP```````+BC````````(``````````@``````````0`
M````````4.5T9`0```!0G````````%"<````````4)P```````#L````````
M`.P`````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````T/L```````#0
M^P$``````-#[`0``````,`0````````P!`````````$`````````!````!0`
M```#````1TY5`-<J;./W-W,%Q@XV$`N@C=:.066U+VQI8C8T+VQD+6QI;G5X
M+6QO;VYG87)C:"UL<#8T9"YS;RXQ```````````1````2@````0````(````
M(!`0``5`!(`H```$@(8`A(*)``()(`0(B(`00;H``@@`````2@```$T```!0
M````40````````!9````6@````````!<````70````````!>````7P```&$`
M`````````````&[%WQ_.WD<M:W^:?"[%F[;49-1\(?_D#MEQ6!SB1\8!L@&+
M;ZQ+X\!"^M>'PN4_++KCDGSZH6Q@F4_#FV>OS&9"1=7LB0=PTS-BV^T5C"7,
M?ZF<F^"G`@IK&IY0H^#[20``````````````````````````````````````
M`````P`+`.`<`````````````````````````P`,`-!:````````````````
M`````````P`.`$"=`````````````````````````P`4`````@``````````
M`````````````P`5`$@``@```````````````````````P`6`%```@``````
M``````````!F`@``$@````````````````````````#5````$@``````````
M``````````````#4`0``$@````````````````````````"'````$@``````
M``````````````````!.`0``$@````````````````````````#,`@``$0``
M``````````````````````#K````$@````````````````````````"R`@``
M$0````````````````````````"V`0``$@````````````````````````#;
M`0``$@````````````````````````"*`@``$@``````````````````````
M``!0`@``$@`````````````````````````<`0``$@``````````````````
M```````,`0``$@````````````````````````#^````$@``````````````
M``````````"(`0``$@`````````````````````````!````(```````````
M``````````````!L`0``$@````````````````````````#L`0``$@``````
M```````````````````=````(``````````````````````````A`@``$@``
M``````````````````````!M`@``$@`````````````````````````"`@``
M$@````````````````````````"5`0``$@`````````````````````````W
M````$@````````````````````````"?`0``$@``````````````````````
M``!4````%@`````````````````````````^`0``$@``````````````````
M``````!G````$@````````````````````````"^`0``$@``````````````
M``````````#$````$@````````````````````````!X````$@``````````
M```````````````W`@``$@````````````````````````#:````$@``````
M``````````````````"O`0``$@````````````````````````!)`@``$0``
M``````````````````````"H````$@````````````````````````!E`0``
M$@````````````````````````"6`P``$@````````````````````````#%
M`0``$@````````````````````````#[`0``$@``````````````````````
M```P`@``$@````````````````````````"1`@``$@``````````````````
M```````P`0``$@````````````````````````"H`@``$@``````````````
M``````````#?````$@````````````````````````!\`@``$@``````````
M``````````````!U`@``$@````````````````````````"3````$@``````
M``````````````````!7`@``(@````````````````````````!9`0``$@``
M``````````````````````"F`0``$@````````````````````````"B`@``
M$@````````````````````````#A`0``$@````````````````````````"W
M````$0`````````````````````````+`@``$@``````````````````````
M``"Z`@``$@`````````````````````````O`@``$@``````````````````
M``````"#`@``$@`````````````````````````E`0``$@``````````````
M``````````!%````$@````````````````````````!W`0``$@``````````
M```````````````3`@``$@````````````````````````#F`0``$@``````
M``````````````````"-`0``$@````````````````````````"P`@``$0``
M``````````````````````#-`0``$@````````````````````````"?`P``
M$@`+`!@^````````&`$```````#G`P``$@`+`$@U````````>`8```````!$
M`@``$@`+`.`<````````[`$````````6`P``$@`+`/`H````````!```````
M```T`P``$@`+`,`[````````5`(````````-!```$@`+`/@H````````9`(`
M``````#-`P``$``6`%```@`````````````````G`P``$@`+`&`K````````
M.`````````!*`P``$@`+`,@Q````````9`````````"K`P``$0`,`-!:````
M````!`````````"Z`P``$@`+`#!6````````?`$```````#%`P``$@`+`/@G
M````````(`````````#B`P``$``6`'@``@````````````````#[`P``$@`+
M`%`T````````]``````````D!```$@`+`#`R````````9`````````!N`P``
M$@`+`)@K````````E`$```````#T`P``$``5`%```@`````````````````:
M!```$0`4`$```@``````"`````````#2`P``$@`+`-`>````````8```````
M``#9`P``$@`+`,!5````````<`````````"$`P``$@`+`"@T````````)```
M``````!8`P``$@`+`!@H````````V`````````!Z`P``$@`+`+!7````````
M"`,````````L!```$@`+`#`M````````E`0`````````7TE435]D97)E9VES
M=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R
M;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!03%]C=7)R96YT7V-O;G1E>'0`
M4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!0
M97)L7V-R;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U
M;7``4&5R;%]N97=84U]F;&%G<P!P97)L7V9R964`4&5R;%]M9U]S970`4&5R
M;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V
M`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,
M;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO
M8P!?7W-T86-K7V-H:U]F86EL`&5X:70`;'-E96LV-`!R96%D9&ER-C0`<W1R
M9'5P`&-L;W-E9&ER`&]P96XV-`!S=')R8VAR`'5N;&EN:P!M96UM;W9E`'-T
M<G1O:P!S=')L96X`<FUD:7(`<F5A9`!M:V1I<@!?7W9F<')I;G1F7V-H:P!G
M971P:60`<F5A9&QI;FL`<F5A;&QO8P!?7W-P<FEN=&9?8VAK`%]?9G!R:6YT
M9E]C:&L`;'-T870V-`!?7VQI8F-?<W1A<G1?;6%I;@!S=&1E<G(`;65M8VAR
M`%]?8WAA7V9I;F%L:7IE`'-T<F-H<@!O<&5N9&ER`&=E='5I9`!A8V-E<W,`
M;65M8W!Y`'-T<F-M<`!?7V5R<FYO7VQO8V%T:6]N`&%B;W)T`'-T<FYC;7``
M7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`%]?<W1A8VM?8VAK7V=U87)D
M`&QI8G!E<FPN<V\N-2XT,`!L:6)C+G-O+C8`;&0M;&EN=7@M;&]O;F=A<F-H
M+6QP-C1D+G-O+C$`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?
M26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?
M97AE8U]P<F]C`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G971?=7-E<FYA;65?
M9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?=7-E9`!S:&%?
M=7!D871E`'AS7VEN:70`7U]B<W-?<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?
M;6MT;7!D:7(`7V5D871A`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O
M9P!M>5]P87)?<&P`<&%R7V1I90!P87)?:6YI=%]E;G8`1TQ)0D-?,BXS-@``
M``````````````````(``0`"``$``0`#``$``@`"``(``@`"``$``0`!``(`
M`0`!``(``0`"``(``@`"``$``@`!``$``0`"``$``0`"``(``@`"``$``@`"
M``(``@`"``(``0`"``$``@`"``$``@`!``(``@`"``$``@`"``(``@`!``$`
M`@`"``(``@`"``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!`/@"```0````(````+:1E@8```,`.00`````
M```!``$`[@(``!``````````MI&6!@```@`Y!````````-#[`0```````P``
M``````!((````````-C[`0```````P````````#P'P```````!```@``````
M`P`````````P7````````!@``@```````P````````"87@```````"```@``
M`````P````````"@7@```````"@``@```````P````````"H7@```````#``
M`@```````P````````"P7@```````$```@```````P````````"X7@``````
M`$@``@```````P````````!(``(``````*C_`0```````@````P`````````
M`````+#_`0```````@````T``````````````+C_`0```````@````X`````
M`````````,#_`0```````@```!<``````````````,C_`0```````@```!H`
M`````````````-#_`0``````"P```"$``````````````-C_`0```````@``
M`"(``````````````.#_`0```````@```",``````````````.C_`0``````
M`@```"H``````````````/#_`0```````@```#@``````````````/C_`0``
M`````@```#T``````````````.#]`0``````!0````<``````````````.C]
M`0``````!0````@``````````````/#]`0``````!0````D`````````````
M`/C]`0``````!0````H```````````````#^`0``````!0````L`````````
M``````C^`0``````!0````\``````````````!#^`0``````!0```!``````
M`````````!C^`0``````!0```!$``````````````"#^`0``````!0```!(`
M`````````````"C^`0``````!0```!,``````````````##^`0``````!0``
M`!0``````````````#C^`0``````!0```!4``````````````$#^`0``````
M!0```!8``````````````$C^`0``````!0```!@``````````````%#^`0``
M````!0```!D``````````````%C^`0``````!0```!L``````````````&#^
M`0``````!0```!P``````````````&C^`0``````!0```!T`````````````
M`'#^`0``````!0```!X``````````````'C^`0``````!0```!\`````````
M`````(#^`0``````!0```"```````````````(C^`0``````!0```"0`````
M`````````)#^`0``````!0```"4``````````````)C^`0``````!0```"8`
M`````````````*#^`0``````!0```"<``````````````*C^`0``````!0``
M`"@``````````````+#^`0``````!0```"D``````````````+C^`0``````
M!0```"L``````````````,#^`0``````!0```"P``````````````,C^`0``
M````!0```"T``````````````-#^`0``````!0```"X``````````````-C^
M`0``````!0```"\``````````````.#^`0``````!0```#``````````````
M`.C^`0``````!0```#$``````````````/#^`0``````!0```#(`````````
M`````/C^`0``````!0```#,```````````````#_`0``````!0```#0`````
M``````````C_`0``````!0```#4``````````````!#_`0``````!0```#8`
M`````````````!C_`0``````!0```#<``````````````"#_`0``````!0``
M`#@``````````````"C_`0``````!0```#D``````````````##_`0``````
M!0```#H``````````````#C_`0``````!0```#L``````````````$#_`0``
M````!0```#P``````````````$C_`0``````!0```#X``````````````%#_
M`0``````!0```#\``````````````%C_`0``````!0```$``````````````
M`&#_`0``````!0```$$``````````````&C_`0``````!0```$(`````````
M`````'#_`0``````!0```$,``````````````'C_`0``````!0```$0`````
M`````````(#_`0``````!0```$4``````````````(C_`0``````!0```$8`
M`````````````)#_`0``````!0```$<``````````````)C_`0``````!0``
M`$D``````````````,X#`!RMO1$`SX'2**U1_P+,@=("K05%`(PAP"C@`0!,
MSP,`'.]!TBCM`0!,``!``\\#`!SO(=(H[0$`3```0`//`P`<[P'2*.T!`$P`
M`$`#SP,`'._AT2CM`0!,``!``\\#`!SOP=$H[0$`3```0`//`P`<[Z'1*.T!
M`$P``$`#SP,`'.^!T2CM`0!,``!``\\#`!SO8=$H[0$`3```0`//`P`<[T'1
M*.T!`$P``$`#SP,`'.\AT2CM`0!,``!``\\#`!SO`=$H[0$`3```0`//`P`<
M[^'0*.T!`$P``$`#SP,`'._!T"CM`0!,``!``\\#`!SOH=`H[0$`3```0`//
M`P`<[X'0*.T!`$P``$`#SP,`'.]AT"CM`0!,``!``\\#`!SO0=`H[0$`3```
M0`//`P`<[R'0*.T!`$P``$`#SP,`'.\!T"CM`0!,``!``\\#`!SOX<\H[0$`
M3```0`//`P`<[\'/*.T!`$P``$`#SP,`'.^ASRCM`0!,``!``\\#`!SO@<\H
M[0$`3```0`//`P`<[V'/*.T!`$P``$`#SP,`'.]!SRCM`0!,``!``\\#`!SO
M(<\H[0$`3```0`//`P`<[P'/*.T!`$P``$`#SP,`'._ASBCM`0!,``!``\\#
M`!SOP<XH[0$`3```0`//`P`<[Z'.*.T!`$P``$`#SP,`'.^!SBCM`0!,``!`
M`\\#`!SO8<XH[0$`3```0`//`P`<[T'.*.T!`$P``$`#SP,`'.\ASBCM`0!,
M``!``\\#`!SO`<XH[0$`3```0`//`P`<[^'-*.T!`$P``$`#SP,`'._!S2CM
M`0!,``!``\\#`!SOH<TH[0$`3```0`//`P`<[X'-*.T!`$P``$`#SP,`'.]A
MS2CM`0!,``!``\\#`!SO0<TH[0$`3```0`//`P`<[R'-*.T!`$P``$`#SP,`
M'.\!S2CM`0!,``!``\\#`!SOX<PH[0$`3```0`//`P`<[\',*.T!`$P``$`#
MSP,`'.^AS"CM`0!,``!``\\#`!SO@<PH[0$`3```0`//`P`<[V',*.T!`$P`
M`$`#SP,`'.]!S"CM`0!,``!``\\#`!SO(<PH[0$`3```0`//`P`<[P',*.T!
M`$P``$`#SP,`'._ARRCM`0!,``!``\\#`!SOP<LH[0$`3```0`//`P`<[Z'+
M*.T!`$P``$`#SP,`'.^!RRCM`0!,``!``\\#`!SO8<LH[0$`3```0`,`````
M````````````````8X#^`F%@P2EX(,$I=T#!*7D`P2EZX,`I^`,`&ABC_B@,
M`P`FC0`5`&5`P"EF(,`I94#``F8@P`)D<,`";*#`*6UP@"G_3_]7Y@,`&L;`
M_BCD`P`:A(#_*,4`%0``?#U4[`,`&HSA_RB,`0`J@!$!0%<8#QCL`P`:C$'_
M*(T)##AY'``DK$D2*B03@`*$#$$`C`V``ZQ)$BG_:_Y7;D#`*.P#`!J1`<$H
MSP$`)G`<`"33!P(8\@<"&.0BP"D-!(`"DR#`*9)@P"F10,`ICP``)SD/@`*'
M`!4`#!"``K`I`&3.(<`"$`Z``L\!`":-`14`K0U!`(P%@`+O-!PXSB'``I#I
M_U_D8L`HC`U!``@`%0#@,!PX)@,5`$5-`!C_E_M7@(@`0.1BP"AZD,`"_V?]
M5YD`%0!%`Q4`1.T!&`!$`E2`=`!`Y&+`*/\[^U?_5_Q7;:#`*`P#`":LB0!<
M86#!*'=`P2AX(,$H>N#`*"0#%0!Y`,$H8X#!`B```$S_Q_M7UP\/&.1BP"F`
M7`!`_U?\5^P#`!J-0?\HK0D,.*W]WP*@/00I_]?^4^1BP"C_5_M7_W?_4^1"
MP"B`#`!``'P?5/^'_U-%`Q4`!.4!&`"T`53D0L`IGW#_0P!@'U3_:_]3_\/]
M5P0$@`+_2_M7``!``XD`%0`D```:#(#S`NS__Q>,_3\#A+`0`&4`P"AF(,`"
M`P"#``<`%0`(`!4`:@`5`"$``!H,0.L"[/__%XS]/P,AL!``(0``3"$``!H,
M`/`"[/__%XS]/P,AL!``(0``3```0`,``$`#``!``P``0`-CP/\"=B#`*79`
MP`+D!P\8S`</&(0M`%CL`P`:C`'_*(`A`$!V(,`H8T#``H`!`$P``$`#``!`
M`P``0`,``$`#=B#`*&-`P`(@``!,``!``\0%#QBE!0\8I9`1`&/`_P*L#$D`
MI?Q%`'8@P"FEL!``=D#``J4$20"@*`!`[`,`&HPA_RB`'0!`=B#`*&-`P`*`
M`0!,``!``P``0`,``$`#=B#`*&-`P`(@``!,``!``V.`_P)V0,`I=R#`*6%@
MP"EV@,`"=P(/&.P"`"J`*0!$S`,`&HS!_RB`$0!`S`,`&H0AP2C_K_M7_QO_
M5PP$@`+L`@`I86#`*'9`P"AW(,`H8X#``B```$QCP/\"=B#`*79`P`)V(,`H
M8T#``O\W_U-C`/\"=\#`*6'@P"E]```GS`,`&HSA_BB=`0`F%P`5`*"7`$!Y
M@,`I>F#`*7M`P"F,```HF@`5`+L`%0"9`!4`#?2``H"U`$"-$0!8+`<`*#D'
MP`*?]?]'.6L1`+<#`";@H@!`>*#`*7P@P"FX`Q4`'/2``@``0`,F`Q4`10,5
M`.0"%0#_G_I7@`P`1.QF(#B<40!8%R/`*!@CP`+_WO]'>*#`*'F`P"AZ8,`H
M>T#`*'P@P"AAX,`H?0``)N0"%0!WP,`H8P#!`B```$P``$`#``!``P``0`,`
M`$`#``!``QCW$0`Y!\`"&`])`/?F$`!X`P`E_Z__4QD`%0#_8_]3>8#`*'I@
MP"A[0,`H_ZO_4V-`_0)W@,(I>&#"*6&@PBG8`P`:&*/^*`P#`"9E(,`"EP`5
M`&P@PBG_J_I7@$0`1&X8`"3L`0`4C0``%(RY%`"-#0!830$`%(TM`%P%"(`"
MY`(5`/_?^5>$!$`"`!@`4```0`,``$`#``!``P``0`,$`!4`;2#"*`P#`":L
M&0!<8:#"*'>`PBAX8,(H8\#"`B```$S_?_I78P#]`GF`PBEAX,(IV0,`&CFC
M_B@L`P`F;"#"*8`8`$!WP,(IC```*I<`%0"`+0!$=\#"*&T@PB@L`P`FK&D!
M7&'@PBAY@,(H8P##`B```$P``$`#``!``WB@PBG_[_=7F``5`(!4`4!Z8,(I
M!`,5`/_[]U>`S`!`C$P`*II,P`*,2;\"C8%``(`)`$1-!P`JO]W_0XQ,`"J,
M2;\"C8%``(`5`$1,!P`JC$F_`HV!0`"`R0!`O[G_0^0"%0![0,(I_ZOV5YL`
M%0!$`Q4`_Y_V5V03$`"$"(`"_S/X5TD#%0#H`A4`9[\!&`;\OP(%!(`"F@`5
M`/^7^5=E(,`"1`,5`/]+^%<,_+\"C!@`6&X8`"3L`0`4C0``%(RY%`"-?0!8
M1`,5`/]W]U=$`Q4`_Z_W5P0#%0![0,(H_S/W5Y\\_T<$`Q4`_Z?X5^0"%0#_
M7_97=\#"*'B@PBAZ8,(H_]O^4P``0`,``$`#``!``P``0`,``$`#``!``TT+
M`"K_._]3``!``P``0`,``$`#``!``P``0`,``$`#1`,5`/]G_E?_B_]3=\#"
M*7B@PBEZ8,(I>T#"*?_'^%=WP,(H>*#"*/]W_E,``$`#8X#^`G=`P2EX(,$I
M>0#!*7O`P"EA8,$I>N#`*7R@P"E]@,`IK```*M@#`!H8H_XH#0,`)HSUP`.,
M!4`"N;`0`)<`%0`D`Q4`;2#`*?]7]5>;`!4`91#``N0"%0#_-_Q7@%`!0)H`
M%0#_._57FP0!;'P$`"3=`P`:O>/^*)P/00#M`@`H[`(5``[T@`*@Y0%`KA$`
M6(T%`"B,!<`"O_7_1XQ=$0"Z`P`F9`O``H2P$`#_D_971',<.(!X`$"M`P`F
M[`(`*.0&P`*N<0PX#_2``LP!`"F`+0!$`+@`4```0`,``$`#``!``P``0`,`
M`$`#C```*(0$P`*L!0`I@)4`0,T!%0#.!<`"C^G_7P_T@`*N!<`"#``5`*\!
M`"D``$`#+3,`.,TQ$#B,!<`"O_7_1VT@P"@,`P`FK$T!7&%@P2AW0,$H>"#!
M*'D`P2AZX,`H>\#`*'R@P"A]@,`H8X#!`B```$P``$`#``!``P``0`,,`!4`
M``!``RTS`#A-,Q`XC`7``K_U_T?_J_]3``!``\T!%0#_>_]3``!``P``0`,`
M`$`#``!``P``0`,``$`#?F#`*7]`P"G=`P`:O>/^*+\#`";L`P`F@+$`0.P#
M%0`:`!4```!``XTAP"A.`Q4`C"'``EH'@`*_\?]'S@V``L0-00"LU`X8C0$`
M)*!5`$0-!(`"C0$`)?\[]5>>`!4`@(``0%P/00#E`Q4`A@,5`/]#]5>^`P`G
M3`>``HP-00#`,QPX?F#`*']`P"AZ$(`I_T/^4P``0`,``$`#``!``X4`%0#D
M`Q4`__OU5Z0#`">>`!4`@"P`0%P/00#_O_]3#``5`/\S_E,$0(`"&@`5`/]W
M_U-^8,`I?T#`*?\G]E=^8,`H?T#`*/^;_E,``$`#8P#_`G?`P"EXH,`I>8#`
M*7I@P"EAX,`IV`,`&ABC_B@,`P`F[?__%6.T$`":`!4`N0`5``;\OP-E(,`"
MI*$!&&P($"?_K_-7EX!``!=H`&3M_K\";+00`(PA`"J`50!`>Q`0)WL@P`+F
M`A4`!;R``F0#%0#_[_)7@)@`0,P#`!J,0?\HA`D,.&8#%0#G`A4`10,5`/__
M\U=[$!`F`#``4```0`,``$`#``!``P``0`.@<0!$S`,`&HQ!_RB$"0PX)@,5
M`$4#%0#_R_)7;0@0)@P#`":L10!<+0``%&.T$`!AX,`H=\#`*'B@P"AY@,`H
M>F#`*&,`P0(@``!,``!``P``0`,``$`#``!``P``0`-[$!`F_Z/_4WL0$"?_
M]_17>Q`0)[<!%0#_/_]3``!``V/`_P)W```G82#`*=<#`!KL0O\HA`D,.(>C
M`QC&`P`:QF#_*&69`1C_F_17]T+_*.0*##AA(,`H=P``)BBU`1@)`!4`YIX`
M&`<!%0`EF0$88T#``O^_\E/,`P`:C$'_*(0)##@GH0,8Q@,`&L9@_R@%EP$8
M_T_T4V/`_@)A(,$I=P#!*7C@P"EYP,`I>J#`*=H#`!I:H_XH3`,`)LW__Q5C
MM!``;!@@)__[\E=W(,`")@``%(@`%0")E@$8IY8!&,8$@`,%!(`"Y`(5`/\G
M]%<L```4C$&``WFP$`#D`A4`)@``%"4#%0#_V_%7EX!``!@`%0#@)@!@Y`:`
M`O]W\E>8`!4`@!0`0.8"%0`E`Q4`_Z/S5P!?$#AM&"`F3`,`)JPM`%Q-```4
M8[00`&$@P2@$`Q4`=P#!*'C@P"AYP,`H>J#`*&-`P0(@``!,_Y?S5_\K_U,`
M`$`#8X#\`G=`PREX(,,I>0##*7O`PBEA8,,I[?__%=L#`!I[H_XH8[00`&T#
M`":9`!4`MP`5`.20`1AE$,`";8@0)_\K]U>8`!4`!;R``B0#%0#_"_!7@%0`
M0$20`1@E`Q4`_WOZ5R0#%0!MB!`F;`,`)JSA`5PM```48[00`&%@PRAW0,,H
M>"##*'D`PRA[P,(H8X##`B```$P``$`#``!``P``0`,``$`#Y`(5`'JX$"=\
MJ!`G?I@0)__C\%>EC0$8_POS5Y<`%0`<_+\#>B#"`GX@P`*`;`%`?:`0)P``
M0`/L`@`J@.4`0``7`$#E`A4`!`,5`/_7[U>`J`!`Y`(5`/][[U>,_/\"[+(0
M`)T`%0`.O(`"["(`:``P`%```$`#``!``P``0`.``0`IC/W_`NP.`%B-`0`J
MKO'_6^0"%0#_.^]7G0`5`"0#%0#_+^]7A/00`(0$P`*$7P!H!02``BH#%0"I
MB`$8Z`(5`*>(`1@F```41`,5`/\C\E?%`Q4`1`,5`/_7\%>`&`!$;A@`).P!
M`!0-`0`4C+D4`(UM`%B%A@$8!``5`/\C\E>7`!4`GS#_1WJX$"9\J!`F?:`0
M)GZ8$";_E_Y3`!\`0`P#`"J,2;\"C8%``(`)`$0-!P`JO\'_0QT$@`(7@P$8
M_U__4P``0`,``$`#``!``P``0`,``$`#``!``P4$@`)$`Q4`_YOP5Y^,_T=%
M`Q4`)((!&/^[^%=$`Q4`_W/O5WJX$"9\J!`F?:`0)GZ8$";_+_Y3>K@0)GRH
M$"9^F!`F_P_^4WJX$"=\J!`G?:`0)WZ8$"?_*_%7``!``V/`_P(%O(`"=P``
M)V$@P"F7`!4`_R_N5XP$P`+WDA,`A!$3`&$@P"B$7!4`=P``)F-`P`+__^Y3
M8T#_`GE`P"EAH,`IV0,`&CFC_B@L`P`F[?__%6.T$`!L"!`G@,@`0'@8$">,
M```JF``5`("U`$!W(!`G_Y_M5RP``!2&!,`"EP`5`(;]`&AM(,`"!0,5`*0!
M%0#_7_!7[/[_`HRP$``.O(`"C"@`:``L`%```$`#``!``P``0`,``$`#``!`
M`X`!`"F,_?\"A`T`6(T!`"JN\?];=R#``@6\@`+D`A4`_V/M5X"\`$#D>@!H
M9"#``O]#[E=M"!`F+`,`)JS!`%PM```4=R`0)G@8$"9CM!``8:#`*'E`P"AC
MP,`"(```3'@8$"9M"!`F+`,`)J1U`1BLD0!<+0``%&.T$`!AH,`H>4#`*&/`
MP`+_Z^U3``!``P``0`,``$`#``!``P``0`.````I_XO_4P``0`,``$`#``!`
M`P``0`,``$`#``!``P0`%0#_<_]3``!``P``0`,``$`#``!``P``0`,``$`#
M;0@0)BP#`":L%0!<=R`0)G@8$"9D<0$8_W__4_]G[U=W(!`G>!@0)_];[U<`
M`$`#8T#_`G>`P"EX8,`I>4#`*6&@P"G8`P`:&*/^*`P#`"9W$,`"V0,`&CGC
M_BAL(,`IY0(5`.1P`1C_^_)7@$0`0&T$`"0O`P`FK0U!`.RU$`".(<`H[C4<
M.-_9_T,``$`#C4'`*(PAP`*-`0`GO_7_1^4"%0#D;@$8_[OR5Y_$_T?9`P`:
M.>/^*.4"%0"D;@$8_Z/R5X!$`$!M!``D+P,`)JT-00#LM1``CB'`*.XU'#C?
MV?]#``!``XU!P"B,(<`"C0$`)[_U_T?E`A4`I&P!&/]C\E>?Q/]'V0,`&CGC
M_BCE`A4`)&P!&/]+\E>`1`!`;00`)"\#`":M#4$`[+40`(XAP"CN-1PXW]G_
M0P``0`.-0<`HC"'``HT!`">_]?]'Y0(5`"1J`1C_"_)7G\3_1]D#`!HYX_XH
MY0(5`.1I`1C_\_%7@$0`0&T$`"0O`P`FK0U!`.RU$`".(<`H[C4<.-_9_T,`
M`$`#C4'`*(PAP`*-`0`GO_7_1^4"%0#D9P$8_[/Q5Y_$_T?9`P`:.>/^*.4"
M%0!D9P$8_YOQ5X!$`$!M!``D+P,`)JT-00#LM1``CB'`*.XU'#C?V?]#``!`
M`XU!P"B,(<`"C0$`)[_U_T?E`A4`9&4!&/];\5>?Q/]'V0,`&CGC_BCE`A4`
M)&4!&/]#\5>`1`!`;00`)"\#`":M#4$`[+40`(XAP"CN-1PXW]G_0P``0`.-
M0<`HC"'``HT!`">_]?]'Y0(5`"1C`1C_`_%7G\3_1]D#`!HYX_XHY0(5`*1>
M`1C_Z_!7@$0`0&T$`"0O`P`FK0U!`.RU$`".(<`H[C4<.-_9_T,``$`#C4'`
M*(PAP`*-`0`GO_7_1^4"%0"D7`$8_ZOP5Y_$_T?9`P`:.>/^*.4"%0`D8`$8
M_Y/P5X!$`$!M!``D+P,`)JT-00#LM1``CB'`*.XU'#C?V?]#``!``XU!P"B,
M(<`"C0$`)[_U_T?E`A4`)%X!&/]3\%>?Q/]'N0,`&CGC_BCE`A4`Y%T!&/\[
M\%>`1`!`;00`)"\#`":M#4$`[+40`(XAP"CN-1PXW]G_0P``0`.-0<`HC"'`
M`HT!`">_]?]'Y0(5`.1;`1C_^^]7G\3_1[D#`!HYX_XHY0(5`*1;`1C_X^]7
M@$0`0&T$`"0O`P`FK0U!`.RU$`".(<`H[C4<.-_9_T,``$`#C4'`*(PAP`*-
M`0`GO_7_1^4"%0"D60$8_Z/O5Y_$_T>Y`P`:.>/^*.4"%0`D5`$8_XOO5X!$
M`$!M!``D+P,`)JT-00#LM1``CB'`*.XU'#C?V?]#``!``XU!P"B,(<`"C0$`
M)[_U_T?E`A4`)%(!&/]+[U>?Q/]'Y0(5`.16`1C_.^]7A0`5`(`,`$!D50$8
M_YOR5^4"%0#$5@$8_Q_O5X4`%0"`#`!`!%<!&/]_\E?E`A4`)%<!&/\#[U>%
M`!4`@#@`0.1.`1C_8_)7;2#`*`P#`":L10!<8:#`*'>`P"AX8,`H>4#`*,56
M`1CD4`$88\#``O\W\E/E`A4`9%4!&/^[[E>%`!4`G\3_0^10`1C_&_)7_[O_
M4__#ZE<``$`#8X#_`G=`P"EA8,`IMP,`&O>B_BCL`@`F91#``F1/`1AL(,`I
M_W?N5XP`%0`$`!4`@!4`0(0!`"B,0/\"#+`2`(01$P!M(,`H[`(`)JP5`%QA
M8,`H=T#`*&.`P`(@``!,_UOJ5P``0`-C@/X"86#`*:\#`!KOH?\HK0,`&JVA
M_BBM`0`FC@`5`.0!`"9LH,`"9:#`*6;`P"EGX,`IQ@$5`(<!%0`%!(`":`#!
M*6D@P2EJ0,$I:V#!*6T@P"EL```G_ZOG5P3\@P+_@^=7``!``V.`_@)W0,$I
M>"#!*7D`P2EZX,`I>\#`*7R@P"E]@,`I?F#`*6%@P2D-_O\5N@,`&EJC_BAC
MM!``3`,`)FT$`!"M(<`"!@B``@4`%0"L`0`GF``5`/_'Z5>7_/\"[?Y)`*W!
M10#LMA``C`'/`(RU$0#WLA$`&?R_`AL<@`)]`!4`7F<.&!S^_Q7@Z@!@``!`
M`P8`%0#E`A4`!`,5`/]_Z5>9X`!8!@(`%*4#%0`$`Q4`QB"``__'Z%>$@$``
MF;P`6&2K`&R,X/\"K+,0`)TE`&P`F`!0``!``P``0`,``$`#``!``P``0`.,
M_?\"G7T`:,X#`":-`0`FS?'_7XSU$0"$W1``;`0`$(PAP`*-`0`F3`,`)JQU
M`%P-`@`48[00`&%@P2AW0,$H>"#!*'D`P2AZX,`H>\#`*'R@P"A]@,`H?F#`
M*&.`P0(@``!,``!``P``0`,``$`#``!``P``0`,``$`#``!``_?^_Q/\)O]?
M!/R_`O^3_U.$0P$8_Q_^5\1"`1C_%_Y7_V/H5P``0`-CP/\"82#`*?^#YU?_
M[^97@`@`0(0``"9A(,`H8T#``B```$P``$`#8P#_`GB@P"EY@,`I8>#`*;D#
M`!HYH_XH+`,`)I@`%0!E$,`"Y$`!&&P@P"G_Y^M7@!@`0'?`P"F,```JEP`5
M`(`Q`$1WP,`H;2#`*"P#`"8%`Q4`9#\!&*R-`%QAX,`H>*#`*'F`P"AC`,$"
M_Q?O4P0#%0!Z8,`I_ZOD5YH`%0#D`A4`_Y_D5T23$`"$",`"_S/F5^H"%0`)
M-`$8"`,5`$<T`1@&_+\"!02``I<`%0#_D^=7;2#`*"P#`":L-0!<>F#`*&'@
MP"AXH,`H>8#`*.4"%0!WP,`H1#L!&&,`P0+_H^Y3=\#`*7I@P"G_1^=7_T/G
M5P``0`-C@/D">"#&*7D`QBEZX,4I3%4.&&%@QBF`00`L8(!!+'=`QBF`@0`L
M8,!!++H#`!I:H_XH@,$`+&``0BQ.`P`F>'#``ID`%0#1.`$8<"T!&,\X`1CM
M.`$8!0,5`"0M`1AQ@,`I<*#`*6#`P"EO`,$I;B#%*6T@P2E@0,$I_Y_J5X`0
M`$",```JEP`5`(`-`T1[P,4I?*#%*7V`Q2G_S^57_SOE5X`4`D"7```FX`X"
M0.0"%0#_=^-7A`1!`(0$P`+_"^57Z`(`*)P`%0";`!4``#$`0```0`,(@6<`
MA`,5``<U`1@&_+\"!02``O]?YE?H!@`HG`O``O<&P`(?W?]'?(#!`B0O`1@`
M'`!0``!``P``0`,``$`#A"/`*)PCP`*`.`!`!0,5`/_SZ5>7`!4`G^C_0XP`
M`"J?X?]#_^_J5Y_8_T/D`A4`_P/D5Y<`%0"`-`!$``!``WR`P`*7`P`FX"8`
M0.P"`"J`,0%`Y`(5`/^[ZE>`!`%$ER/`*)PCP`+_YO]'Y`(5`/^CXE>=`!4`
M9`,5`/^7XE>]$Q``O1.0`J0#%0#_)^17:P,5`.HN`1C)(P$8Z`(5`,<N`1@&
M_+\"!02``IP`%0#_@^57!0"'`H0#%0#_A^57#/R_`HP4`%S_.^17B0``)`Q$
M@`(L=0%<94#"`H0#%0#_`^57EP`5`(`8`$1NH``D[`$`%(T``!2,N10`C24!
M6*P#`!J,H?\H)P,`)H0!`":(`Q4`IBT!&`4$@`+_Q^)7&P`5````0`-M(,4H
M3`,`)JP5!%QA8,8H?*#%*'V`Q2AW0,8H>"#&*'D`QBAZX,4H9`,5`'O`Q2AC
M@,8"(```3.0"%0#_S^)7EP`5`)PCP`*?U/Y#__O^4P``0`,``$`#%P`5`/_K
M_E,``$`#``!``P``0`,``$`#``!``P``0`-[`,$"``!``V0#`":`)`!`!0,5
M`/]/Z%>`#`!`C```*H!!`$1D(\`H>R/``I_D_T<$-(`"_]_B5YP`%0`W(P$8
M"$R!`IL`%0#_V_U3``!``P``0`,``$`#``!``P``0`/_,^)7EP`5`'LCP`*?
MG/]#_P/A5X0$00"$!,`"_X_]4WNH`"3_+^-79-O^7VR@`"1^8,4I#0"'`HS]
M1P.-=0!8?F#%*/^__E.L`P`:C*'_*"<#`":$`0`FB`,5`&8A`1@%!(`"_W_A
M5_^[_E,``$`#``!``P``0`,``$`#``!``_]S^U=M(,4H3`,`)JS!`EQA8,8H
M>"#&*'D`QBAZX,4HY`(5`'=`QBAC@,8"_X?A4Z0#%0#__^%7!0,5`)L`%0`$
M(P$8_S_G5X4`%0"`5`%`)`,`)O_'[U>>`!4`@$0!0,0#%0#_+^!7G8!```P,
M@`*=,0!DI//_`H4A`1C$DQ``_V/@5X`<`$0,$(`"K/L!6+WOOP+-=R`X#+R`
M`JSI`5@%`Q4`9!(!&/_;YE>`%`%`C```*(`-`4`-P(`"C04!6$46`1AD$0$8
M_ROJ5_^7X5>*`!4`:R8!&,D-`1B(`Q4`QQ\!&`;\OP(%!(`"9`,5`/_#XE<8
M_+\"&42``CTE`1@`7`!0``!``P``0`,``$`#``!``P``0`,``$`#``!``_]C
MX5>,```DF44`7/\WX5?W!H`"B@`5`'T``">I"@$8ZP(5`(@#%0`''0$8!OR_
M`@4$@`)D`Q4`_UOB5P4`AP)D`Q4`_U_B5YBX_UN$`Q4`_Y/@5V4#%0"$!P$8
M_W?I5V0#%0#_[_E7?F#%*/\?_5,``$`#``!``P``0`,``$`#/@,`)O^__E,`
M`$`#``!``P``0`,``$`#``!``P``0`,%`!4`Q`,5`/]+X%>8`!4`G_#^0__G
M]U>9`!4`@.3^8X78_P(&`!4`!`,5`/_GX5=]0,0"!AB``@0#%0"E`Q4`_S/A
M5PP8@`*,M`!<;1`!)(R"AA2,`8P#K*G^7ZT30"J,```4C"&5`ZR9_E\&`!4`
M)3O_`@0#%0#_F^%7=V#$`@:@@`($`Q4`Y0(5`/_GX%<,H(`"C&@`7$L:`1CJ
M`A4`B0$!&(@#%0`'$P$8!OR_`@4$@`)D`Q4`8``%*?\WX5?_[_Y3.2/`*#\;
M_D,D`Q4`_P/>5PP,@`*$"?YOA/#_`H40`1@DDQ``_SO>5]X3$P`DDQ,`WA,5
M`/_K_5/D#P$8_Y/V5WY@Q2G_V^!7>\#%*7R@Q2E]@,4I?F#%*?_'X%=C`/\"
M=\#`*7F`P"EZ8,`I8>#`*7B@P"E[0,`IN0,`&CFC_B@L`P`FMP,`&GH0P`)L
M(,`I[$+_*)@)##BD_0`810,5``S#`BH,QP(I_U?D5X`0`$"-```J#,2``JRE
M`5C_$_%7[$+_*)@)##@$`Q4`!PR``@8$@`)%#0$8_[?=5Y@`%0"`,`!`C$#`
M*.U"_RBD"0PXA0$`)H8,`1C_I]U7#$/`*(4!`":L#``DC%G6`("1`43L0O\H
MA`D,.`<,@`(&!(`"90L!&/]KW5>8`!4`6QX.&(`L`$!%`Q4`Y/4`&/_#XU<,
M0\`HA@`5`(4!`":`,`%`[$+_*(0)##C_1]U7[$+_*)@)##@&!(`"90D!&`0#
M%0#_K]Q7A0`5`*8)`1@$`Q4`_Q_=5_="_RCL"@PX10,5`*3R`!B`Q0(I_V?C
M5V1#P"F7`!4`@)@`0`4`AP+D`A4`_X_?5PP$@`*-!(`"C4$`;`Q$@`*,.`!8
M;"/`*(<`%0#F`A4`A0$`)B0(`1C_@]Y7``!``P``0`,``$`#``!``P``0`,`
M`$`#``!``VT@P"@L`P`FK*D`7&'@P"AWP,`H>*#`*'F`P"AZ8,`H>T#`*&,`
MP0(@``!,``!``P``0`,``$`#``!``P``0`-D(\`H_Z?W5V1#P"F7`!4`GUS_
M1R0#`1C_"]Y7``!``XP$`"J?:?Y#_UO^4P``0`,``$`#``!``P``0`,``$`#
M;"/`**0`%0"%`0`F_X?H5__3_E,``$`#``!``P``0`/L0O\HA`D,./^+W5?_
M:_Y3_W/>5P``0`-C0/\"=X#`*7A@P"EAH,`IMP,`&O>B_BCL`@`FF``5`&40
MP`*D[``8;"#`*?\?XE>`(`!`C```*(`9`$`-P(`"C1$`6``/`$`,`P`J@#T`
M1&T@P"CL`@`FK+D`7&&@P"AW@,`H>&#`*&/`P`(@``!,``!``P``0`,``$`#
M``!``P``0`,``$`#!`,5`'E`P"G_\^Q7!;R``ID`%0#_[]I7C`3``CF3$P"$
M$1,`A&05`/_+VU<&$(`"!?``&/^OW%>`*`!`>4#`*/^+_U,``$`#``!``P``
M0`,``$`#``!``P``0`,``$`#;2#`*.P"`":L)0!<>4#`*&&@P"AW@,`H!`,5
M`'A@P"ACP,`"_^?B4WE`P"G_5]U7``!``P``0`,``$`#``!``[0#`!J4HOXH
MC`(`)F.`]0+G`0`486#**7=`RBEQ`!4`YP"\`W(`%0`&_@$4D.#``H7@P0)L
M(,HI#P(`)@T"`"120L`"[H%%`.RA10#384$`[^%%`(R=%`",/14`K3$``,XA
M00!O`M\`K<%,`,Z9%`",/14`K0'?`(PY%0`0(L`"3<+_*4SB_RD%LO]?;*#!
M`F!``"QG@``L9L``+"VBR0)C``$L94`!+&2``2QAP`$L8@`G<8EA/BR``0`L
M*`#4<XQ!P`(`)"=Q``@G<0%\,7..X0(8``0M<R&`)G'``0`L(0`F<8$A0"S@
M`-1SQP#4<V8`U'.C`-1SA0#4<P0!U'.-L?]?D@``)FX``":3@,`HY02U%*5D
MI@.10,`HCR#`*)!@P"A);D4`3!9!`(PE%0#.E1``SLT0`(P!WP`MPA4`Z0E%
M`(RY$`#N>4$`:"#`**V]%`#.)14`R0'?`*W!%0",M1``+:85``B5$`"MR10`
MC`'?``C!$`"MQ14`BFU%`*VA$`"(%4$`""D5`&=`P"A*"D4`K:$0`$AZ00`(
M*14`9F#`*,ZA%0#GE!``SK$4`*T!WP#GQ!``QI00`,ZE%0#&I!``SIT0`*D5
M00"G;44`*1T5`(=Y00","44`YS`5`,RE$``.G14`"0'?`,ZU%`",`=\`SJ45
M`,Z9$`"(;44`AA5!`,8@%0"H>4$`K0E%``@U%0#-F1``;H#`**8!WP#MH!4`
MZP#?`,Z5$`"ML10`SJ40`*VM%0#*%$$`K;D0`,YL10!..14`AWE!`(P)10#G
M,!4`K+D0`&V@P"B.`=\`#)T5`*V5$``(`=\`C)D4`*VM$`",H14`R15!`(RU
M$`#-;44`*345`(RE$`#*>$$`S0A%`$8U%0"-`=\`;,#`*.H`WP"I%4$`C)40
M`(BA$`#LF!4`C+D4`*=M10",J14`C*$0`"@=%0",H1``:.#`*,=Y00#."44`
MYS@5``B5$`".`=\`S)P5``BI$`",M10`R@#?`,D500#&;44`C*D5`(RA$``H
M&14`C*$0`&@`P2BF>4$`K0E%`,8T%0`(E1``C0'?`.R8%0`(J1``C+D4`.H`
MWP"I%4$`IVU%`(RI%0",H1``*!T5`(RA$`!H(,$HQWE!`,X)10#G.!4`")40
M`(X!WP#,G!4`"*D0`(RU%`#*`-\`R15!`,9M10",J14`C*$0`"@9%0",H1``
M:$#!**9Y00"M"44`QC05``B5$`"-`=\`[)@5``BI$`",N10`Z@#?`*D500"G
M;44`C*D5`(RA$``H'14`C*$0`&A@P2C'>4$`S@E%`.<X%0`(E1``C@'?`,R<
M%0`(J1``C+44`,H`WP#)%4$`QFU%`(RI%0",H1``*!D5`(RA$`!H@,$HIGE!
M`*T)10#&-!4`")40`(T!WP#LF!4`"*D0`(RY%`#J`-\`J15!`*=M10",J14`
MC*$0`"@=%0",H1``:*#!*,=Y00#."44`YS@5``B5$`".`=\`S)P5``BI$`",
MM10`R@#?`,D500#&;44`C*D5`(RA$``H&14`C*$0`&C`P2BF>4$`K0E%`,8T
M%0`(E1``C0'?`.R8%0`(J1``C+D4`.H`WP"I%4$`IVU%`(RI%0",H1``*!T5
M`(RA$`!HX,$HQWE!`,X)10#G.!4`")40`(X!WP#,G!4`"*D0`(RU%`#*`-\`
MR15!`,9M10",J14`C*$0`"@9%0",H1``IGE!`&@`PBBM"44`QC05`(T!WP#L
MF!4`")40`.<`WP",N10`"*D0`(R=%0"I%4$`C*$0`*AM10`H(14`C*$0`,EY
M00#."44`*3D5`(X!WP!L(,(HR@#?`,@500",E1``AYT0`,RD%0",M10`QFU%
M`(RI%0",G1``!QD5`(R=$`"H>4$`9T#"**T)10`(-14`+:$5`.>4$``I`=\`
MK;D4`(P!WP#GJ!``K:45`*V=$`"&%4$`AVU%`,8<%0#+>4$`S@E%`&LY%0#.
M`-\`IKD0`&Y@PB@-K14`K;$4``@!WP#%E1``QP#?`*6D$`"MH14`K940`.X4
M00#E;$4`SA45`(IY00","44`2C$5`&6`PBC,`=\`KK$0`,VSW12MA:X#;*D5
M`(R9%0"EM!``R0'?`*6@$`",`=\`C)40`"9M10`E%4$`I1@5`*4`WP"%E1``
M;*#"**8`WP#H>$$`:P'?`(RU$`#G"$4`!QT5`(RM$`#(%$$`RVQ%``@M%0!+
MG14`;KD5`,X!WP`(`=\`C+D0`(ZA$`!LP,(H2@'?`,@!WP",M1``C*D0`"IY
M00`I"44`2245``L500`*;44`:RD5`.JD%0!%E14`I0#?`&L!WP",E1``A:T0
M`&S@PBCJ`-\`IP#?`(RU$`",J1``RGA!`,8(10!*&14`ZVQ%`.8400#&+!4`
M*ZD5`&ZY%0#.`=\`Q@#?`(RY$`".F1``;`##*"D!WP#&`=\`C+40`(RE$``)
M>4$`"`E%`"DA%0#+;$4`R!1!``@M%0!+I14`9945`*4`WP`(`=\`C)40`(6A
M$`!L(,,H2@'?`*@`WP",M1``C*D0`.IX00#G"$4`2AT5``MM10`'%4$`YRP5
M`"NI%0!NN14`S@'?`.<`WP",N1``CIT0`&Q`PR@I`=\`QP'?`(RU$`",I1``
MR7A!`,8(10`I&14`ZVQ%`.8400#&+!4`2Z45`&65%0"E`-\`Q@#?`(R5$`"%
MF1``;&##*$H!WP"F`-\`C+40`(RI$``*>4$`"`E%`$HA%0#+;$4`R!1!``@M
M%0`KJ14`;KD5`,X!WP`(`=\`C+D0`(ZA$`!L@,,H*0'?`,@!WP",M1``C*40
M`.EX00#G"$4`*1T5``MM10`'%4$`YRP5`$NE%0!EE14`I0#?`.<`WP",E1``
MA9T0`&R@PRA*`=\`IP#?`(RU$`",J1``RGA!`,8(10!*&14`ZVQ%`.8400#&
M+!4`*ZD5`&ZY%0#.`=\`Q@#?`(RY$`".F1``;,##*"D!WP#&`=\`C+40`(RE
M$``)>4$`"`E%`"DA%0#+;$4`R!1!``@M%0!+I14`9945`*4`WP`(`=\`C)40
M`(6A$`!LX,,H2@'?`*@`WP",M1``C*D0`.IX00#G"$4`2AT5``MM10`'%4$`
MYRP5`"NI%0!NN14`S@'?`.<`WP",N1``CIT0`&P`Q"@I`=\`QP'?`(RU$`",
MI1``R7A!`,8(10`I&14`ZVQ%`.8400#&+!4`2Z45`&65%0"E`-\`Q@#?`(R5
M$`"%F1``;"#$*$H!WP"F`-\`C+40`(RI$``*>4$`"`E%`$HA%0#+;$4`R!1!
M``@M%0`KJ14`;KD5`,X!WP`(`=\`C+D0`(ZA$`!L0,0H*0'?`,@!WP",M1``
MC*40`.EX00#G"$4`*1T5``MM10`'%4$`YRP5`$NE%0!EE14`I0#?`.<`WP",
ME1``A9T0`&Q@Q"A*`=\`IP#?`(RU$`",J1``RGA!`,8(10!*&14`ZVQ%`.84
M00#&+!4`*ZD5`&ZY%0#.`=\`Q@#?`(RY$`".F1``;(#$*"D!WP#&`=\`C+40
M`(RE$``)>4$`"`E%`"DA%0#+;$4`R!1!``@M%0!+I14`9945`*4`WP`(`=\`
MC)40`(6A$`!LH,0H2@'?`*@`WP",M1``C*D0`.IX00#G"$4`1QT5``MM10`*
M%4$`2BT5`"N=%0!NN14`S@'?`$H!WP",N1``CJD0`&S`Q"@I`=\`RGA!`(RU
M$`",I1``:>#$*,8(10!*&14`*;40`.VH%0"ME14`RP'?`*T!WP!E;44`YP#?
M`(RU$`!M%4$`*9T0`*T5%0`'>4$`!0E%`.<4%0!%G14`KK@5`,X!WP",M1``
M);D0`&D`Q2AN-QX5A@'?`&T)10!L>4$`SG&S`PX``!:,-14`RQ1!`,UL10!K
M-14`*;D0`$T!WP"(`=\`*;40`.TP%0"EK!``K9D4`.N@%`"M+14`K:40`&D@
MQ2BE`-\`YP#?`"FY$`"J%$$`*9T0`*=L10!''14`K9T0`,=X00#&"$4`YQ@5
M`(P=%0"F`=\`C)44`.V@%`",-14`C*40`&E`Q2C-%$$`Z@#?`"FY$``IH1``
MR&Q%`*TA%0",M1``K7A!`*4(10"M%14`J`'?`.4T%0"EF!0`YZ`4`*4<%0"E
MI!``:6#%*(P!WP"'%4$`*;D0`"FI$`"*;44`YR@5`*6<$`#'>$$`Q@A%`.<8
M%0"M'14`I@#?`*VQ%`#EH!0`K145`*VE$`!I@,4HQ11!`.H`WP`IN1``*:$0
M`,AL10"E(!4`K940`(5Y00","44`K#`5`(@!WP#E,!4`I9@4`.>@%`"E'!4`
MI:00`&F@Q2BM`=\`IQ5!`"FY$``IJ1``JFU%`.<H%0"EG!``QWA!`,8(10#G
M&!4`C!T5`*8`WP",M10`Y:`4`(P5%0",I1``:<#%*,4400#J`-\`*;D0`"FA
M$`#(;$4`I2`5`(R5$`"E>4$`K0E%`*TT%0"H`=\`Y305`*68%`#GH!0`I1P5
M`*6D$`!IX,4HC`'?`(<500`IN1``*:D0`(IM10#G*!4`I9P0`,=X00#&"$4`
MYQ@5`*T=%0"F`-\`K;$4`.6@%`"M%14`K:40`&D`QBC%%$$`Z@#?`"FY$``I
MH1``R&Q%`*4@%0"ME1``A7E!`(P)10"L,!4`B`'?`.4P%0"EF!0`YZ`4`*4<
M%0"EI!``:2#&**T!WP"G%4$`*;D0`"FI$`"J;44`YR@5`*6<$`#'>$$`Q@A%
M`.<8%0",'14`I@#?`(RU%`#EH!0`C!45`(RE$`!I0,8HQ11!`.H`WP`IN1``
M*:$0`,AL10"E(!4`C)40`*5Y00"M"44`K305`*@!WP#E-!4`I9@4`.>@%`"E
M'!4`I:00`&E@QBB,`=\`AQ5!`"FY$``IJ1``BFU%`.<H%0"EG!``QWA!`,8(
M10#G&!4`K1T5`*8`WP"ML10`Y:`4`*T5%0"MI1``:8#&*,4400#J`-\`*;D0
M`"FA$`#(;$4`I2`5`*V5$`"%>4$`C`E%`*PP%0"(`=\`Y3`5`*68%`#GH!0`
MI1P5`*6D$`!IH,8HK0'?`*<500`IN1``*:D0`*IM10#G*!4`I9P0`,=X00#&
M"$4`YQ@5`(P=%0"F`-\`C+44`.6@%`",%14`C*40`&G`QBC%%$$`Z@#?`"FY
M$``IH1``R&Q%`*4@%0",E1``I7E!`*T)10"M-!4`J`'?`.4T%0"EF!0`YZ`4
M`*4<%0"EI!``:>#&*(P!WP"'%4$`*;D0`"FI$`"*;44`YR@5`*6<$`#'>$$`
MQ@A%`.<8%0"M'14`I@#?`*VQ%`#EH!0`K145`*VE$`!I`,<HQ11!`.H`WP`I
MN1``*:$0`,AL10"E(!4`K940`(5Y00","44`K#`5`(@!WP#E,!4`I9@4`.>@
M%`"E'!4`I:00`&D@QRBM`=\`IQ5!`"FY$``IJ1``JFU%`.<H%0"EG!``QWA!
M`,8(10#G&!4`C!T5`.:@%`",M10`I0#?`(P9%0",I1``IA1!`*EL10#&)!4`
MC)D0`*9Y00"M"44`S305`&9`QRBI`=\`Z@#?`,:X$`#(H!``YC05`,:4%`#G
MI!0`C`'?`,8<%0#&H!``AQ5!`(AM10#G(!4`:&#'**MX00#G`-\`#KD0`,JI
M$`"N"$4`93D5`,:<$`"M%14`QP#?`*ZD%`"ML10`Z!1!`*TY%0#N;$4`#CD5
M`(MY00","44`:S$5`*VI$`#,`=\`KK$0`&J`QRB-Q905K5F'`PT``!:LK!4`
MC)D5`$:U$`#(`=\`QJ00`(P!WP",F1``"6U%``8500#&)!4`=Z#'*,8`WP"&
MF1``R0#?`*4`WP#WMA``ZGA!`.<(10!*'14`+&U%`/>6$``E%4$`I3`5`&RI
M%0",N14`C`'?`(S=$`"E`-\`A940`&S`QRBG`-\`#GE!`&L!WP",M1``"`E%
M`,@A%0",K1``[A1!`.ML10#.+14`2Z$5`&:9%0#&`-\`C)D0`,X!WP".N1``
M;.#'*$H!WP#&`=\`C+40`(RI$``J>4$`*0E%`$HE%0#+%$$`R6Q%`&LE%0`)
MJ14`)945`*4`WP!K`=\`C)40`(6M$`!L`,@H"0'?`*@`WP",M1``C*40`.EX
M00#G"$4`*1T5``MM10`'%4$`YRP5`$NE%0!NN14`S@'?`.<`WP",N1``CIT0
M`&P@R"A*`=\`QP'?`(RU$`",J1``RGA!`,8(10!&&14`ZQ1!`.IL10!K*14`
M*ID5`$65%0"E`-\`:P'?`(R5$`"%K1``;$#(*"H!WP"I`-\`C+40`(RI$``*
M>4$`"`E%`$@A%0`K%4$`*FU%`&LI%0#*H!4`3KD5`,X!WP!K`=\`C+D0`(ZM
M$`!L8,@HR@#?`,8!WP",M1``C*D0`.IX00#G"$4`1QT5`,L400#*;$4`:RD5
M``J=%0!%E14`I0#?`&L!WP",E1``A:T0`&R`R"@*`=\`J`#?`(RU$`",J1``
M*GE!`"D)10!))14`"Q5!``IM10!K*14`ZJ05`$ZY%0#.`=\`:P'?`(RY$`".
MK1``;*#(*.H`WP#'`=\`C+40`(RI$`#*>$$`Q@A%`$89%0#K%$$`ZFQ%`&LI
M%0`JF14`1945`*4`WP!K`=\`C)40`(6M$`!LP,@H*@'?`*D`WP",M1``C*D0
M``IY00`("44`2"$5`"L500`J;44`:RD5`,J@%0!.N14`S@'?`&L!WP",N1``
MCJT0`&S@R"C*`-\`Q@'?`(RU$`",J1``ZGA!`.<(10!''14`RQ1!`,IL10!K
M*14`"IT5`$65%0"E`-\`:P'?`(R5$`"%K1``;`#)*`H!WP"H`-\`C+40`(RI
M$``J>4$`*0E%`$DE%0`+%4$`"FU%`&LI%0#JI!4`3KD5`,X!WP!K`=\`C+D0
M`(ZM$`!L(,DHZ@#?`,<!WP",M1``C*D0`,IX00#&"$4`1AD5`.L400#J;$4`
M:RD5`"J9%0!%E14`I0#?`&L!WP",E1``A:T0`&Q`R2@J`=\`J0#?`(RU$`",
MJ1``"GE!``@)10!*(14`*Q5!`"AM10!K(14`R*@5``ZY%0#.`=\`:P'?`(RY
M$`".K1``;&#)*,@`WP#&`=\`C+40`(RA$`#H>$$`YPA%``@=%0#+%$$`QVQ%
M`&L=%0!'H14`Y905`*4`WP!K`=\`C)40`(6M$`!L@,DH1P'?`*H`WP",M1``
MC)T0`"=Y00`I"44`YR05`$L500!);44`:R45``F=%0`NN14`S@'?`&L!WP",
MN1``CJT0`&R@R2@)`=\`R`'?`(RU$`",I1``R7A!`,8(10`I&14`"VU%``85
M00#&+!4`ZZ05`&N5%0#E`-\`9P'?`,8`WP",G1``AYD0`&S`R2A&>4$`2@E%
M`,8H%0",M1``C)40`"69%0"NN!4`S@'?`(RY$`!NX,DHZP#?`"D!WP#-M1``
MK<D0`*6E$`!N;44`;0E%`&H500!R>4$`4C85`$TY%0`.>4$`"`E%`,XA%0",
MM1``S;@5`%'&$`",`=\`K9T5`,[!$`"2;44`,`+?`*T!WP"1%4$`C+T0`(P!
MWP`O2A4`K;00`(P@P"FLO1``C`'?`-/,$`!S`M\`C```)Y.`P"ES(,HHC`(`
M)LX!WP"00,`ICF#`*6P6`%QA8,HH=T#**&.`R@(@``!,_\?&5V/`_P($`(("
M82#`*?]'Q5=0F]\5KW4Q%<VEAQ51BLX4$":N`^_YLP.N9"`4K<&'`S$&C`,0
M```6#P``%L[9D0,-```6D0``)Y`@P"F/0,`ICF#`*8V`P"F`H,`I@,#`*8#@
M@2EA(,`H8T#``B```$QCP/X">.#`*7G`P"EZH,`I?&#`*6$@P2EW`,$IC*#`
M*(_`P"C.=$4`S3`M`*T!WP"LL1(`[[$0`)!X`"3,O1``C:#`*8S`P"F9`!4`
MV@`5`+P`%0"8X,`"`-H`1`S\@`*:A0!D?4#`*5V;1`![@,`INP/?`'L;00"]
M_[\"?B#`*9<#%0"^`]\`F^\0````0`/B0@`LX8(`+.#"`"SC`@`L)`,5``,#
M0"P"0T`L`8-`+/<"P0(`PT`L_UOH5_O6_U^]FT``WAM!`%H#OP*<`\$"6G<1
M`-SS$`![@,`H?4#`*'X@P"A&`Q4`A0,5``0#%0#_,\57.N.!*6$@P2AW`,$H
M>.#`*'G`P"AZH,`H?&#`*&-`P0(@``!,``!``P``0`,``$`#``!``P``0`,`
M`$`#%P"!`O="$0#,7!(`][(3`,PP$P#W,A4`!,,0`.8"%0#_T\17+'L`)`T`
M@0*,71``+..!*8V5_U\D`Q4`6E\1`)S?$`#_G^=7_^?^4P``0`-C0/\"K*#`
M*'H@P"E[```GNB@`)+LP`"2,#<@`=X#`*7A@P"EY0,`I8:#`*;G@P`(/`+X"
M6C,``'LS``".!8`"+S,0.`W@@`*W`!4`F``5`%K#3`![PTP`++L0`*Y5`60-
M`($"#Q"``JTY$0"OA0)L#@B``JY=`FR@.0)$Y`(5`/\3YU?@XL`I("/`*2!#
MP"D@8\`I((/`*2"CP"D@P\`I^\*!*?K2@2GD`A4`_^?F5^P"`";D`A4`C&%%
M``P#`"GL`@`FC$%%``P'`"GL`@`FC"%%``P+`"GL`@`F#`\`*>PBP"B,844`
M#!,`*>PBP"B,044`#!<`*>PBP"B,(44`#!L`*>PBP"@,'P`I[$+`*(QA10`,
M(P`I[$+`*(Q!10`,)P`I[$+`*(PA10`,*P`I[$+`*`PO`"GL8L`HC&%%``PS
M`"GL8L`HC$%%``PW`"GL8L`HC"%%``P[`"GL8L`H##\`*>R"P"B,844`#$,`
M*>R"P"B,044`#$<`*>R"P"B,(44`#$L`*>R"P"@,3P`I8:#`*'>`P"AX8,`H
M>4#`*'H@P"A[```F8\#``O^'P5,-X(`"#X"``JTY$0"OM0!L#D"``JZ-`&P.
M((`"KF4`;`X0@`*N/0!L#@B``JX5`&R_P?Y#@`$`*?^[_E,``$`#@`%`*:WY
M_P*,"<`"OZ7^0__G_U,``$`#``!``P``0`.``0`EK?'_`@X(@`*,$<`"KL'_
M:__/_U,``$`#``!``X`!`">MX?\"#A"``HPAP`*NF?]K_\__4P``0`,``$`#
M@`$`)X`AP"FMP?\"#B"``HQ!P`*N;?]K_\O_4P``0`,@.QPXK8'_`@Y`@`*`
M(<`I@$'`*8!AP"F,@<`"KCW_:__#_U,``$`#``!``P``0`,``$`#``!``P``
M0`,``$`#@`$`*?_+_5,``$`#``!``P``0`,``$`#``!``P``0`.``4`IK?G_
M`HP)P`*_H?U#_]/_4P``0`,``$`#``!``R`[&#BM\?\"#@B``HP1P`*N>?UK
M_\__4VP#`!J'(<$H_W/!4P````````````````$``@``````)7,O)7,````O
M<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R````
M``!);G1E<FYA;',Z.E!!4CHZ0D]/5`````!E>&4``````"]P<F]C+R5I+R5S
M```````N`````````%!!4E]414U0``````````!005)?4%)/1TY!344`````
M.@`````````O`````````"5S)7,E<P``4$523#5,24(``````````%!%4DQ,
M24(`4$523#5/4%0``````````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!
M4E]34$%73D5$``````!005)?0TQ%04X`````````4$%27T1%0E5'````````
M`%!!4E]#04-(10````````!005)?1TQ/0D%,7T1%0E5'``````````!005)?
M1TQ/0D%,7U1-4$1)4@````````!005)?5$U01$E2````````4$%27T=,3T)!
M3%]414U0`%!!4E]'3$]"04Q?0TQ%04X``````````#$`````````;'-E96L@
M9F%I;&5D`````')E860@9F%I;&5D``````!,1%],24)205)97U!!5$@`4UE3
M5$5-```O=&UP`````%5315(`````55-%4DY!344``````````"4P,G@`````
M<&%R+0`````E<R5S)7,E<P``````````)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@```````"5S
M.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R
M96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H```````!0051(
M`````'!A<FP`````+G!A<@````!S:&]R="!R96%D````````)7,E<V-A8VAE
M+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S````````
M```8`````````'!E<FP`````,`````````!005(Z.E!A8VME<CHZ5D524TE/
M3@`````Q+C`V,P```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y
M```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E
M8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```````````M90```````"TM
M````````5$U01$E2``!414U01$E2`%1%35``````5$U0``````!E=F%L("=E
M>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N
M;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P[
M"FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@)&-A8VAE7VYA
M;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*
M)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I"B1C86-H95]N
M86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P,UPP,#0B.PI]
M"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\["FUY("1C:'5N
M:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1F
M:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E("1C:'5N:U]S
M:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N
M:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L("1P;W,L(#`[
M"G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!
M1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@
M/CT@,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@)&-H=6YK7W-I
M>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@
M0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#
M3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A
M<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE
M.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V
M:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D
M97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E
M;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/
M(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%
M35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^
M(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D
M=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M
M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H
M96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@
M)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE
M;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B
M.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R
M;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*
M0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN
M=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM
M>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H
M7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X
M92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_
M("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN
M?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S
M*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP
M*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!]
M(ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD[
M"DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIU;FQE
M<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#
M86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U
M<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#
M.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J7T9(*3L*:68@
M*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S
M=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S
M="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@<&]S:71I;VX@
M)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F
M9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E860@7T9(+"`D
M8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@(EPP0T%#2$4B
M("8F("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A8VAE(&UA<FME
M<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C:&4@;6%R:V5R
M("(D8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%
M7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)3$5?;V9F<V5T
M7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F*3L*;W5T<R@B
M3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E="(I.PIS965K
M(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@)&]F9G-E
M="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@7T9(.PIM>2`E
M<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@
M("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H
M)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U
M9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM
M>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@
M/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^
M(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR
M96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D
M*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM
M>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U
M*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N
M86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L
M;&YA;64["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB
M=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I]
M.PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U
M9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L
M92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM
M>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S
M<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[
M)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[
M4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E
M871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN
M="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@[
M"GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R
M8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N
M86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q
M<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*
M9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@
M)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER
M92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X
M<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O
M<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I
M;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE
M;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L
M<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U
M<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE
M;F%M97T["GT*:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2!["F]U=',H<7%;
M3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O
M9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?
M1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`
M<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N
M86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@
M*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF("@A)'-T87)T
M7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T
M*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I
M;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@
M('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR
M975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S
M:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*
M;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O
M7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@
M)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G
M32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N
M<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O
M=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET
M92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*
M96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E
M<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG
M="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G
M*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@
M)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0
M)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I
M<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D
M9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]
M"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D
M("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q
M6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@
M)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C
M:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*:68@*"1Z:7`@
M86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*
M)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS
M.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E
M9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D
M:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U
M9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@
M<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)0SL*8VQO<V4@
M)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?
M4D174B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@
M<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D
M92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@
M)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@)&QO861E<BP@
M)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C86P@)"\@/2!U
M;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%4
M24U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H)&QO861E<BD*
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D;W5T(CH@)"%=
M.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M
M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"![
M"B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L
M:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN
M8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID
M;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@
M)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E
M>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS
M;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F
M:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E
M86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O
M*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0[
M"GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@
M*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I
M(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D
M9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]
M"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[
M)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<
M+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,
M12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE
M*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]
M("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E
M;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D
M("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@)'1H.PI0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E
M9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M
M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]
M"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K
M(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E
M0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O
M;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&5M
M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;5W)I='1E;B!A
M<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW<FET951O1FEL
M94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*?0II9B`H)&UE
M=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.(BD["GT*96QS
M92!["FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D8W1X(#T@1&EG
M97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C='@M/F%D9&9I
M;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE(#T@)&-T>"T^
M:&5X9&EG97-T.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE
M+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N/2`B7#`B('@@
M*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD9F@M
M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY("1O9F9S970@
M/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^<')I;G0H<&%C
M:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC;&]S92!O<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T(CH@)"%=.PIC
M:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE
M9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE
M.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H
M:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E
M;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D
M.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY
M("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R
M;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R
M-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG('II<"XN+B(I
M.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S
M970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^
M;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@
M)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S
M("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O
M;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N
M86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE
M*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T
M7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI
M('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A
M;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T
M<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE
M(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA
M;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R
M(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M92)=.PIC:&UO
M9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]
M"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@
M(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M
M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@
M70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]
M"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I
M;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&
M:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E
M<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U
M;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS
M=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN
M84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q
M=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E
M<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP
M;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L
M.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q
M=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA
M;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI
M8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$[
M"G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2
M.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T
M97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS
M,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E
M<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E
M(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E
M<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER
M92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2![
M"B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H
M"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2
M(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@
M=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T
M:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@
M9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97
M:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I
M;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]
M("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@
M?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M<&1I<B`]("(D
M<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I
M.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I<CL*:68@*"1%
M3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PI]"F5L
M<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q
M<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H;7D@)&UA9VEC
M7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*<V5E:R`D9F@L
M("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#
M04-(12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@;&5N9W1H*")<
M,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@
M)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!
M0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F:"P@)&)U9BP@
M)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD8V%C:&5?9&ER
M(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF("@A)&-A8VAE
M7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6>U!!4E]#3$5!
M3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD8V%C:&5?9&ER
M(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%35!](#T@)'-T
M;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?
M87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F
M=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL
M;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;7D@)&9H
M.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@*'!R:6YT("1F
M:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E+"`D=&5M<&YA
M;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN
M86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE
M.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?
M4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2![
M"B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6
M>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0
M?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD
M97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6
M>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI
M;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@
M>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?
M97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*?0I]
M"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L
M("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@
M86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S>7-[
M7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U]
M)'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[
M7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D
M9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER
M)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE
M('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@
M*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N
M86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H
M9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F
M:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D
M8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S
M>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@
M*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@
M96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@
M4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2![
M"F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!435!$25(@5$5-
M4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@)$5.5GLB4$%2
M7T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/0D%,7R1?(GT[
M"GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!
M3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G
M9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?
M7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@
M0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@
M<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB
M97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M
M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P
M87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A
M;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL
M92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R
M;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH
M*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I
M9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)2
M3U(["C$["E]?14Y$7U\*`'!E<FQX<VDN8P``````````0T%#2$4``/____\`
M````_____P`````!&P,[[````!P```"0@/__5`8``(""__\$`0``$(3__Q@!
M```@A?__<`$``+B%__^<`0``@(?___P!```@BO__7`(``%"+__^P`@``J(O_
M_]`"``#(B___Y`(``*",__\<`P``J(S__S`#```0C___H`,``$B/___``P``
MX)#__R0$``!XE?__5`0``."5__]X!```2);__Y`$``#8E___V`0```"8___T
M!```^)C__T@%``!PG___U`4``,BA__\,!@``\*+__X@&``!PN?__L`8``."Y
M___0!@``8+O__Q0'``!HOO__4`<````````0``````````%Z4@`!>`$!&PT#
M`!`````8````=('__V``````!P$`5````"P```#P@O__$`$```!$#D!4EP*!
M`9T(7)D$F@6;!GB8`YP'>-A$V43:1-M$W$3!1-U(UT0.`%@.0($!EP*8`YD$
MF@6;!IP'G0A8V-Q,V43:1-L``"@```"$````J(/__Y@`````1`ZP`4R7`I@#
M@0$"=`K!1-=$V$0.`$0+````7````+`````4A/__Q`$```!$#L`!2)D$@0%<
MEP),UU#!1-E$#@!,#L`!@0&7`ID$1)@#4)H%`E2;!@)XVUP*UT381-I<"V";
M!DS7V-K;4)<"F`.:!9L&1-K;1-=$V```7````!`!``!\A?__G`(```!$#F!D
MEP*8`YD$FP:!`9H%G`>="`,8`0K!1-=$V$391-I$VT3<1-U$#@!0"P)0G@F?
M"@)X"MY$WU0+8-[?2)X)GPI,WM](G@F?"DC>1-\`4````'`!``"\A___+`$`
M``!$#D!4EP*8`YD$F@6!`50.P"!XFP9XVP)$#D!$P4371-A$V43:1`X`6`[`
M(($!EP*8`YD$F@6;!D3;2`J;!D0+1)L&'````,0!``"8B/__6`````!$#A!(
MEP*!`6S!1-=8#@`0````Y`$``-"(__\@`````````#0```#X`0``W(C__]@`
M````1`Y05($!EP*8`YD$F@54#M!``H@*#E!$P4C71-A$V43:1`X`1`L`$```
M`#`"``!\B?__!`````````!L````1`(``'")__]D`@```$0.X`%8EP*8`YD$
MFP:!`4P.X"$"5`H.X`%$P4371-A$V43;1`X`5`M0F@6<!YX)9)T(`MP*VD3<
M1-U$WD0+`FC:1-Q$W43>1)H%G`>>"43:1-Q$WE2:!9P'G0B>"0``'````+0"
M``!HB___.`````!$#A!,EP*!`5C!2-=$#@!@````U`(``("+__^4`0```$0.
M,$B9!($!5`ZP(%"8`TR7`@*4UT381`XP1,%$V40.`$0.L""!`9@#F01$V%@.
M,$3!1-E$#@!8#K`@@0&7`I@#F00"4`K71-A("T37V$B7`I@#+````#@#``"T
MC/__E`0```!$#C!0EP*8`YD$@0$#0`0*P4371-A$V4P.`$0+````(````&@#
M```<D?__9`````!$#B!(EP*!`0)("L%$UT0.`$0+%````(P#``!@D?__9```
M``!$#F!$@0D`1````*0#``"PD?__C`$```!$#F!HEP*8`YD$F@6;!IP'G0B>
M"8$!3`[@@`0"Z`H.8$3!1-=$V$391-I$VT3<1-U$WD0.`&`+&````.P#``#X
MDO__)`````!$#A!$@0%4P40.`%`````(!```!)/___0`````1`Y`3)@#F02!
M`6R7`DS76,%$V$391`X`1`Y`@0&7`I@#F01(F@4"3-I$P4381-E(UT@.`$0.
M0($!F`.9!$B7`IH%`(@```!<!```J)/__W@&````1`Z@`VB8`YD$F@6!`9<"
M`G";!IP'G0@#M`$*P43<1-U$UT381-E$VDC;1`X`1`L#W`">"4C>`CS;W-U4
MP4381-E$VDC71`X`1`Z@`X$!EP*8`YD$F@6;!IP'G0B>"0-<`0K>5`L#)`'>
M1)X)1-O<W=Y0FP:<!YT(G@D`-````.@$``"4F?__5`(```!$#D!8EP*9!)H%
M@0&8`YL&`Y0!"L%$UT381-E$VD3;1`X`6`L```!$````(`4``+2;__\8`0``
M`$0.,$R7`I@#@0$"4`K!1-=$V$0.`%P+2)D$>-E@F010V43!1-=(V$0.`$0.
M,($!EP*8`T29!``P````:`4``#1Z___L`0```$0.8%2!`9@#EP*9!)H%`T@!
M"L%$UT381-I(V40.`$0+````)````)P%``!@G/__@!8```!0#J`%3($!EP(#
M5!8*P4371`X`1`L``!P```#$!0``N++__W``````1`X02($!`ES!1`X`````
M0````.0%```(L___?`$```!$#E`"1)@#F02:!9P'@0&7`F"="$B;!E">"0)<
MVT3=1-Y8"L%$UT381-E$VD3<1`X`7`LX````*`8``$2T__\(`P```$0.,$R:
M!9L&7)<"F`.9!($!`V@!"L%$UT381-E$VD3;1`X`1`L````````0````9`8`
M`!"W__\,```````````````$````$`````$```!'3E4```````4````3````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````2"````````#P'P````````$`````
M````W@(````````!`````````.X"`````````0````````#X`@```````!D`
M````````T/L!```````;``````````@`````````&@````````#8^P$`````
M`!P`````````"`````````#U_O]O`````,`"````````!0````````#(#```
M``````8`````````F`,````````*`````````$0$````````"P`````````8
M`````````!4````````````````````#`````````-#]`0```````@``````
M``!`!0```````!0`````````!P`````````7`````````/`3````````!P``
M```````0$@````````@`````````X`$````````)`````````!@`````````
M'@`````````8`````````/O__V\``````0``"`````#^__]O`````-`1````
M````____;P`````"`````````/#__V\`````#!$```````#Y__]O``````D`
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#_____
M_____P``````````,!D````````P&0```````#`9````````,!D````````P
M&0```````#`9````````,!D````````P&0```````#`9````````,!D`````
M```P&0```````#`9````````,!D````````P&0```````#`9````````,!D`
M```````P&0```````#`9````````,!D````````P&0```````#`9````````
M,!D````````P&0```````#`9````````,!D````````P&0```````#`9````
M````,!D````````P&0```````#`9````````,!D````````P&0```````#`9
M````````,!D````````P&0```````#`9````````,!D````````P&0``````
M`#`9````````,!D````````P&0```````#`9````````,!D````````P&0``
M`````#`9````````,!D````````P&0```````#`9````````,!D````````P
M&0```````#`9````````,!D````````P&0```````#`9````````,!D`````
M```P&0```````.#[`0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````I005(N<&T*```````````P7````````)A>````
M````H%X```````"H7@```````+!>``````````````````"X7@```````$@`
M`@``````1T-#.B`H1&5B:6%N(#$T+C(N,"TQ-RD@,30N,BXP```N<VAS=')T
M86(`+FYO=&4N9VYU+F)U:6QD+6ED`"YI;G1E<G``+F=N=2YH87-H`"YD>6YS
M>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N
M9'EN`"YR96QA+G!L=``N=&5X=``N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H
M7V9R86UE`"YN;W1E+D%"22UT86<`+FEN:71?87)R87D`+F9I;FE?87)R87D`
M+F1Y;F%M:6,`+F=O=``N9&%T80`N<V1A=&$`+F)S<P`N8V]M;65N=```````
M````````````````````````````````````````````````````````````
M``````````````````````````L````'`````@````````!P`@```````'`"
M````````)`````````````````````0````````````````````>`````0``
M``(`````````E`(```````"4`@```````"4````````````````````!````
M````````````````)@```/;__V\"`````````,`"````````P`(```````#4
M``````````0`````````"````````````````````#`````+`````@``````
M``"8`P```````)@#````````,`D````````%````!P````@`````````&```
M```````X`````P````(`````````R`P```````#(#````````$0$````````
M```````````!````````````````````0````/___V\"``````````P1````
M````#!$```````#$``````````0``````````@`````````"`````````$T`
M``#^__]O`@````````#0$0```````-`1````````0``````````%`````@``
M``@```````````````````!<````!`````(`````````$!(````````0$@``
M`````.`!````````!``````````(`````````!@`````````9@````0```!"
M`````````/`3````````\!,```````!`!0````````0````3````"```````
M```8`````````&L````!````!@`````````P&0```````#`9````````H`,`
M`````````````````!``````````$`````````!P`````0````8`````````
MX!P```````#@'````````.0]```````````````````@````````````````
M````=@````$````"`````````-!:````````T%H```````"`00``````````
M````````$````````````````````'X````!`````@````````!0G```````
M`%"<````````[`````````````````````0```````````````````",````
M`0````(`````````0)T```````!`G0```````'@&```````````````````(
M````````````````````E@````<````"`````````+BC````````N*,`````
M```@````````````````````!````````````````````*0````.`````P``
M``````#0^P$``````-#[````````"`````````````````````@`````````
M"`````````"P````#P````,`````````V/L!``````#8^P````````@`````
M```````````````(``````````@`````````O`````8````#`````````.#[
M`0``````X/L```````#P`0````````4`````````"``````````0````````
M`,4````!`````P````````#0_0$``````-#]````````,`(`````````````
M``````@`````````"`````````#*`````0````,````````````"````````
M``$``````$@````````````````````(````````````````````T`````$`
M```#`````````$@``@``````2``!```````(````````````````````"```
M`````````````````-<````(`````P````````!0``(``````%```0``````
M*`````````````````````@```````````````````#<`````0```#``````
M``````````````!0``$``````!\````````````````````!``````````$`
M`````````0````,`````````````````````````;P`!``````#E````````
9`````````````0``````````````````````
